
Sandboxing
-------

**Example:**



    <iframe sandbox="value"> 

	sandbox=""  Applies all restrictions
	allow-forms  Re-enables form submission
	allow-pointer-lock  Re-enables APIs
	allow-popups  Re-enables popups
	allow-same-origin  Allows the iframe content to be treated as being from the same origin
	allow-scripts  Re-enables scripts
	allow-top-navigation  Allows the iframe content to navigate its top-level browsing context


	